package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AppCheckImageType;

/**
 * 打卡图片类型Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface AppCheckImageTypeMapper 
{
    /**
     * 查询打卡图片类型
     * 
     * @param checkImageTypeId 打卡图片类型主键
     * @return 打卡图片类型
     */
    public AppCheckImageType selectAppCheckImageTypeByCheckImageTypeId(Long checkImageTypeId);

    /**
     * 查询打卡图片类型列表
     * 
     * @param appCheckImageType 打卡图片类型
     * @return 打卡图片类型集合
     */
    public List<AppCheckImageType> selectAppCheckImageTypeList(AppCheckImageType appCheckImageType);

    /**
     * 新增打卡图片类型
     * 
     * @param appCheckImageType 打卡图片类型
     * @return 结果
     */
    public int insertAppCheckImageType(AppCheckImageType appCheckImageType);

    /**
     * 修改打卡图片类型
     * 
     * @param appCheckImageType 打卡图片类型
     * @return 结果
     */
    public int updateAppCheckImageType(AppCheckImageType appCheckImageType);

    /**
     * 删除打卡图片类型
     * 
     * @param checkImageTypeId 打卡图片类型主键
     * @return 结果
     */
    public int deleteAppCheckImageTypeByCheckImageTypeId(Long checkImageTypeId);

    /**
     * 批量删除打卡图片类型
     * 
     * @param checkImageTypeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppCheckImageTypeByCheckImageTypeIds(Long[] checkImageTypeIds);

    /**
     * 查询打卡图片类型列表
     *
     * @return 打卡图片类型集合
     */
    public List<AppCheckImageType> getAppCheckImageTypeList();
}
